@@ -464,8 +464,9 @@ class Ui_MainWindow(object):
         MainWindow.setWindowTitle(_translate("MainWindow", "Behavior Data Extracter"))
         self.datafolder_button.setText(_translate("MainWindow", "Data folder"))
         self.medpctoexcel_button.setText(_translate("MainWindow", "MED-PC to Excel"))
-        self.override.setItemText(0, _translate("MainWindow", "Override existing data"))
-        self.override.setItemText(1, _translate("MainWindow", "Skip existing data"))
+        self.override.setItemText(0, _translate("MainWindow", "Override"))
+        self.override.setItemText(1, _translate("MainWindow", "Replace"))
+        self.override.setItemText(2, _translate("MainWindow", "Append"))
         self.medpctoexcel_progressbar.setFormat(_translate("MainWindow", "%p%"))
         self.tabs.setTabText(self.tabs.indexOf(self.genExcel), _translate("MainWindow", "Generate Excel"))
         self.load_datafile.setText(_translate("MainWindow", "Load file"))
@@ -482,7 +483,7 @@ class Ui_MainWindow(object):
         self.genVar_button.setText(_translate("MainWindow", "Generate Variables"))
         self.genVar_progressbar.setFormat(_translate("MainWindow", "%p%"))
         self.tabs.setTabText(self.tabs.indexOf(self.genVar), _translate("MainWindow", "Generate Variable"))
-        self.info_label.setText(_translate("MainWindow", "Current version v2.0.1 \n"
+        self.info_label.setText(_translate("MainWindow", "Current version v2.0.3 \n"
 "Created by Yifeng Cheng, Ph.D. \n"
 "Contact:\n"
 "(979)571-8531\n"
@@ -601,11 +602,11 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
         target_event = events_str.split(',')
         session_time_min = float(sessiondur_str)
         
-        # file = self.filepath
-
-        # df_dict = {rat: pd.read_excel(file, sheet_name = str(rat)) for rat in rat_ids}
+        file = self.filepath
+        
         rat_ids = self.data_explr_rat_ids
-        df_dict = self.data_explr_df_dict
+        df_dict = {rat: pd.read_excel(file, sheet_name = str(rat)) for rat in rat_ids}
+        # df_dict = self.data_explr_df_dict
         
         #Load plot configuration
         mpl.rcParams['font.family'] = 'Arial Narrow'
@@ -636,6 +637,8 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
         
         # fig1.set_size_inches(8.5, 7)
         
+        props_inplot = dict(boxstyle = 'round', facecolor = 'red', edgecolor = 'none', alpha = 0.2)
+        
         for fig_n, rat in enumerate(rat_ids):
             if len(rat_ids) == 1:
                 ax = axes
@@ -646,9 +649,20 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
             
             label_pos = []
             labels = []
+            counts = []
+            lat = []
+            mean_iei = []
+            min_iei = []
+            max_iei = []
             for n,e in enumerate(target_event):
                 x = df[e].values
-                ax.eventplot(x/60, orientation = 'horizontal', lineoffsets = (n+0.5), linelengths = 0.8, linewidths = 0.5, color = color_list[n])
+                counts.append(sum((x/60) < session_time_min))
+                lat.append(x[0])
+                iei = np.diff(x[(x/60) < session_time_min])
+                mean_iei.append(np.mean(iei))
+                min_iei.append(min(iei))
+                max_iei.append(max(iei))
+                ax.eventplot(x/60, orientation = 'horizontal', lineoffsets = (n+0.5), linelengths = 0.5, linewidths = 0.5, color = color_list[n])
                 label_pos.append(n+0.5)
                 labels.append(e[3:])
                 
@@ -670,6 +684,10 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
             ax.set_yticks(label_pos)
             ax.set_yticklabels(labels)
             ax.set_xlim(-0.5, session_time_min+0.5)
+            
+            for idx, count in enumerate(counts,1):
+                text = 'count = %s,lat(s) = %.2f\nmean_IEI(s) = %.2f [max = %.2fs, min = %.2fs]'%(count, lat[idx-1], mean_iei[idx-1], max_iei[idx-1], min_iei[idx-1])
+                ax.text(0, idx/len(counts), text, transform = ax.transAxes, fontsize = 8, verticalalignment = 'top', bbox = props_inplot)
                 
         mplcursors.cursor(highlight=True).connect("add", lambda sel: sel.annotation.set_text(sel.artist.get_label()))
         # fig1.patch.set_facecolor('none')
